import sys
from typing import List

if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


class ConferenceProperties(TypedDict):
    allowedConferenceSolutionTypes: List[str]


class Calendar(TypedDict):
    kind: str
    etag: str
    id: str
    summary: str
    description: str
    location: str
    timeZone: str
    conferenceProperties: ConferenceProperties


import sys
from typing import List

if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


class Attendee(TypedDict):
    id: str
    email: str
    displayName: str
    organizer: bool
    responseStatus: str
    self: bool
    resource: bool
    optional: bool
    responseStatus: str
    comment: str
    additionalGuests: int


class Date(TypedDict):
    dateTime: str
    date: str
    timeZone: str


class Person(TypedDict):
    id: str
    email: str
    displayName: str
    self: bool


class ExtendedProperties(TypedDict):
    private: dict
    shared: dict


class ConferenceSolutionKey(TypedDict):
    type: str


class ConferenceSolution(TypedDict):
    key: ConferenceSolutionKey
    name: str
    iconUri: str


class StatusCode(TypedDict):
    code: str


class ConferenceDataCreateRequest(TypedDict):
    requestId: str
    conferenceSolutionKey: ConferenceSolutionKey
    status: StatusCode


class EntryPoint(TypedDict):
    entryPointType: str
    uri: str
    label: str
    pin: str
    accessCode: str
    meetingCode: str
    passcode: str
    password: str


class ConferenceData(TypedDict):
    createRequest: ConferenceDataCreateRequest
    entryPoints: List[EntryPoint]
    conferenceSolution: ConferenceSolution
    conferenceId: str
    signature: str
    notes: str


class Gadget(TypedDict):
    type: str
    title: str
    link: str
    iconLink: str
    width: int
    height: int
    display: str
    preferences: dict


class Override(TypedDict):
    method: str
    minutes: int


class Reminders(TypedDict):
    useDefault: bool
    overrides: List[Override]


class Source(TypedDict):
    url: str
    title: str


class Attachment(TypedDict):
    fileUrl: str
    title: str
    mimeType: str
    iconLink: str
    fileId: str


class Event(TypedDict):
    """
    Type hint support for a Google Calendar Event Resource.
    https://developers.google.com/calendar/api/v3/reference/events?hl=en#resource-representations
    """

    kind: str
    etag: str
    id: str
    status: str
    htmlLink: str
    created: str  # RFC3339 timestamp
    updated: str  # RFC3339 timestamp
    summary: str
    description: str
    location: str
    colorId: str
    creator: Person
    organizer: Person
    start: Date
    end: Date
    endTimeUnspecified: bool
    recurrence: List[str]
    recurringEventId: str
    originalStartTime: Date
    transparency: str
    visibility: str
    iCalUID: str
    sequence: int
    attendees: List[Attendee]
    attendeesOmitted: bool
    extendedProperties: ExtendedProperties
    hangoutLink: str
    conferenceData: ConferenceData
    gadget: Gadget
    anyoneCanAddSelf: bool
    guestsCanInviteOthers: bool
    guestsCanModify: bool
    guestsCanSeeOtherGuests: bool
    privateCopy: bool
    locked: bool
    reminders: Reminders
    source: Source
    attachments: List[Attachment]
    eventType: str



import sys
from typing import List, Tuple

from black import Dict

if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


class ColorProperties(TypedDict):
    background: str
    foreground: str


class Color(TypedDict):
    kind: str
    updated: str
    calendar: Dict[str, ColorProperties]
    event: Dict[str, ColorProperties]


import sys
from typing import List

if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


class Scope(TypedDict):
    type: str
    value: str


class Acl(TypedDict):
    kind: str
    etag: str
    id: str
    scope: Scope
    role: str



from setuptools import setup, find_packages

with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name="typings-google-calendar-api",
    version="1.0.0",
    author="Lazaro Suleiman",
    author_email="lazaro.fl@gmail.com",
    description="Python typehint support for Google Calendar API resources",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/lazarofl/typings-google-calendar-api",
    packages=find_packages(),
    install_requires=[
        'typing_extensions',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)